@@ -615,7 +615,7 @@ defmodule EarmarkParser do
 
   The AST is exposed in the spirit of [Floki's](https://hex.pm/packages/floki).
   """
-  @spec as_ast(binary()|list(binary()), any()) :: t()
+  @spec as_ast(binary() | list(binary()), any()) :: t()
   def as_ast(lines, options \\ %Options{})
 
   def as_ast(lines, %Options{} = options) do
@@ -644,7 +644,7 @@ defmodule EarmarkParser do
   end
 
   def as_ast(_, options) do
-    raise ArgumentError, "#{inspect options} not a legal options map or keyword list"
+    raise ArgumentError, "#{inspect(options)} not a legal options map or keyword list"
   end
 
   defp _as_ast(lines, options) do
@@ -657,8 +657,9 @@ defmodule EarmarkParser do
     `iex` usage.
   """
   def version() do
-    with {:ok, version} <- :application.get_key(:earmark_parser, :vsn),
-      do: to_string(version)
+    with {:ok, version} <- :application.get_key(:earmark_parser, :vsn) do
+      to_string(version)
+    end
   end
 end
 
