@@ -1,17 +1,31 @@
 defmodule EarmarkParser.Helpers.LineHelpers do
-
   @moduledoc false
 
   alias EarmarkParser.Line
 
-  def blank?(%Line.Blank{}),   do: true
-  def blank?(_),               do: false
+  def blank?(%Line.Blank{}) do
+    true
+  end
 
-  def blockquote_or_text?(%Line.BlockQuote{}), do: true
-  def blockquote_or_text?(struct),             do: text?(struct)
+  def blank?(_) do
+    false
+  end
 
-  def indent_or_blank?(%Line.Indent{}), do: true
-  def indent_or_blank?(line),           do: blank?(line)
+  def blockquote_or_text?(%Line.BlockQuote{}) do
+    true
+  end
+
+  def blockquote_or_text?(struct) do
+    text?(struct)
+  end
+
+  def indent_or_blank?(%Line.Indent{}) do
+    true
+  end
+
+  def indent_or_blank?(line) do
+    blank?(line)
+  end
 
   # Gruber's tests have
   #
@@ -27,10 +41,18 @@ defmodule EarmarkParser.Helpers.LineHelpers do
   #
   # I think the second is a better interpretation, so I commented
   # out the 2nd match below.
-  def text?(%Line.Text{}),      do: true
-  def text?(%Line.TableLine{}), do: true
-#  def text?(%Line.ListItem{}), do: true
-  def text?(_),                 do: false
+  def text?(%Line.Text{}) do
+    true
+  end
 
+  def text?(%Line.TableLine{}) do
+    true
+  end
+
+  #  def text?(%Line.ListItem{}), do: true
+  def text?(_) do
+    false
+  end
 end
+
 # SPDX-License-Identifier: Apache-2.0
