@@ -2,7 +2,6 @@ defmodule Test.Acceptance.Ast.Lists.ComplexBodyTest do
   use Support.AcceptanceTestCase
   import Support.AstHelpers, only: [ast_from_md: 1, ast_with_errors: 1]
 
-
   describe "Ending Bodies" do
     test "blank lines have no impact anymore" do
       markdown = """
@@ -11,9 +10,11 @@ defmodule Test.Acceptance.Ast.Lists.ComplexBodyTest do
 
         World
       """
+
       expected = [ul(li(tags("p", ["Hello", "World"])))]
       assert ast_from_md(markdown) == expected
     end
+
     test "blank lines and negative indent" do
       markdown = """
       * Hello
@@ -21,6 +22,7 @@ defmodule Test.Acceptance.Ast.Lists.ComplexBodyTest do
 
       World
       """
+
       expected = [ul("Hello"), p("World")]
       assert ast_from_md(markdown) == expected
     end
@@ -33,7 +35,9 @@ defmodule Test.Acceptance.Ast.Lists.ComplexBodyTest do
 
         ` World
       """
-      expected = {[ul(li(tags("p", ["Hello", "` World"])))] ,[{:warning, 3, "Closing unclosed backquotes ` at end of input"}]}
+
+      expected =
+        {[ul(li(tags("p", ["Hello", "` World"])))], [{:warning, 3, "Closing unclosed backquotes ` at end of input"}]}
 
       assert ast_with_errors(markdown) == expected
     end
@@ -44,12 +48,15 @@ defmodule Test.Acceptance.Ast.Lists.ComplexBodyTest do
       * Again
         ` World
       """
+
       expected = {
         [ul(["Hello", "Again\n` World"])],
-        [{:warning, 3, "Closing unclosed backquotes ` at end of input"}]}
+        [{:warning, 3, "Closing unclosed backquotes ` at end of input"}]
+      }
 
       assert ast_with_errors(markdown) == expected
     end
   end
 end
+
 #  SPDX-License-Identifier: Apache-2.0
