@@ -9,6 +9,7 @@ defmodule Acceptance.Renderer.AstWalkerTest do
 
       assert walk_ast(ast, &replace_empty/1) == expected
     end
+
     test "can descend" do
       ast = [tags("p", ["alpha", "empty"])]
       expected = [tags("p", ["alpha", []])]
@@ -17,7 +18,13 @@ defmodule Acceptance.Renderer.AstWalkerTest do
     end
   end
 
-  def replace_empty("empty"), do: []
-  def replace_empty(str), do: str
+  def replace_empty("empty") do
+    []
+  end
+
+  def replace_empty(str) do
+    str
+  end
 end
+
 # SPDX-License-Identifier: Apache-2.0
