@@ -1,5 +1,5 @@
 defmodule Support.Parser do
-  def parse_lines lines do
+  def parse_lines(lines) do
     EarmarkParser.Parser.parse(%EarmarkParser.Options{}, lines, false)
   end
 end
