@@ -1,6 +1,5 @@
 defmodule Support.WipHelpers do
-  
-  defmacro assert_size list, size do
+  defmacro assert_size(list, size) do
     quote do
       assert Enum.count(unquote(list)) == unquote(size)
     end
